summaryrefslogtreecommitdiffstats
path: root/src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java')
-rw-r--r--src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java b/src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java
index 75395bd4c..7a1ddd38e 100644
--- a/src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java
+++ b/src/android/app/src/main/java/org/yuzu/yuzu_emu/NativeLibrary.java
@@ -141,9 +141,9 @@ public final class NativeLibrary {
* Gets the embedded icon within the given ROM.
*
* @param filename the file path to the ROM.
* @return an integer array containing the color data for the icon.
*/
- public static native int[] GetIcon(String filename);
+ public static native byte[] GetIcon(String filename);
/**
* Gets the embedded title of the given ISO/ROM.
@@ -205,6 +205,11 @@ public final class NativeLibrary {
public static native void StopEmulation();
/**
+ * Resets the in-memory ROM metadata cache.
+ */
+ public static native void ResetRomMetadata();
+
+ /**
* Returns true if emulation is running (or is paused).
*/
public static native boolean IsRunning();
@@ -141,9 +141,9 @@ public final class NativeLibrary {
*
* @param filename the file path to the ROM.
- * @return an integer array containing the color data for the icon.
+ * @return a byte array containing the JPEG data for the icon.
*/